<div align="center">
	<img width="200" src="docs/logo.png" alt="logo"></br>

# NoneBot Adapter Telegram

_✨ Telegram 协议适配 ✨_

</div>

## Manual

[使用指南](./MANUAL.md)

## TODO

- [ ] Inline Mode Support
- [x] Multiple Bot Support
- [ ] All Event (with docstring)
- [ ] All Method (with docstring)
- [ ] All MessageSegment (with docstring)